==> waypoint-0.11.1.tar.gz: waypoint-0.11.1/pkg/server/singleprocess/service_config.go <==
package singleprocess

import (
	"context"

	empty "google.golang.org/protobuf/types/known/emptypb"

	"github.com/hashicorp/go-hclog"
	pb "github.com/hashicorp/waypoint/pkg/server/gen"
	"github.com/hashicorp/waypoint/pkg/server/hcerr"
	"github.com/hashicorp/waypoint/pkg/server/ptypes"
)

func (s *Service) SetConfig(
	ctx context.Context,
	req *pb.ConfigSetRequest,
) (*pb.ConfigSetResponse, error) {
	if err := s.state(ctx).ConfigSet(ctx, req.Variables...); err != nil {
		return nil, hcerr.Externalize(hclog.FromContext(ctx), err, "failed to set config")
	}

	return &pb.ConfigSetResponse{}, nil
}

func (s *Service) GetConfig(
	ctx context.Context,
	req *pb.ConfigGetRequest,
) (*pb.ConfigGetResponse, error) {
	if err := ptypes.ValidateGetConfigRequest(req); err != nil {
		return nil, err
	}

	vars, err := s.state(ctx).ConfigGet(ctx, req)
	if err != nil {
		return nil, hcerr.Externalize(hclog.FromContext(ctx), err, "failed to get config")
	}

	return &pb.ConfigGetResponse{Variables: vars}, nil
}

func (s *Service) SetConfigSource(
	ctx context.Context,
	req *pb.SetConfigSourceRequest,
) (*empty.Empty, error) {
	if err := ptypes.ValidateSetConfigSourceRequest(req); err != nil {
		return nil, err
	}

	if err := s.state(ctx).ConfigSourceSet(ctx, req.ConfigSource); err != nil {
		return nil, hcerr.Externalize(
			hclog.FromContext(ctx),
			err,
			"failed to set config source",
		)
	}

	return &empty.Empty{}, nil
}

func (s *Service) GetConfigSource(
	ctx context.Context,
	req *pb.GetConfigSourceRequest,
) (*pb.GetConfigSourceResponse, error) {
	if err := ptypes.ValidateGetConfigSourceRequest(req); err != nil {
		return nil, err
	}

	vars, err := s.state(ctx).ConfigSourceGet(ctx, req)
	if err != nil {
		return nil, hcerr.Externalize(
			hclog.FromContext(ctx),
			err,
			"failed to get config source",
		)
	}

	return &pb.GetConfigSourceResponse{ConfigSources: vars}, nil
}

==> waypoint-0.11.2.tar.gz: waypoint-0.11.2/pkg/server/singleprocess/service_config.go <==
package singleprocess

import (
	"context"

	empty "google.golang.org/protobuf/types/known/emptypb"

	"github.com/hashicorp/go-hclog"
	pb "github.com/hashicorp/waypoint/pkg/server/gen"
	"github.com/hashicorp/waypoint/pkg/server/hcerr"
	"github.com/hashicorp/waypoint/pkg/server/ptypes"
)

func (s *Service) SetConfig(
	ctx context.Context,
	req *pb.ConfigSetRequest,
) (*pb.ConfigSetResponse, error) {
	if err := ptypes.ValidateSetConfigRequest(req); err != nil {
		return nil, err
	}

	if err := s.state(ctx).ConfigSet(ctx, req.Variables...); err != nil {
		return nil, hcerr.Externalize(hclog.FromContext(ctx), err, "failed to set config")
	}

	return &pb.ConfigSetResponse{}, nil
}

func (s *Service) DeleteConfig(
	ctx context.Context,
	req *pb.ConfigDeleteRequest,
) (*pb.ConfigDeleteResponse, error) {
	if err := ptypes.ValidateDeleteConfigRequest(req); err != nil {
		return nil, err
	}

	if err := s.state(ctx).ConfigDelete(ctx, req.Variables...); err != nil {
		return nil, hcerr.Externalize(hclog.FromContext(ctx), err, "failed to delete config")
	}

	return &pb.ConfigDeleteResponse{}, nil
}

func (s *Service) GetConfig(
	ctx context.Context,
	req *pb.ConfigGetRequest,
) (*pb.ConfigGetResponse, error) {
	if err := ptypes.ValidateGetConfigRequest(req); err != nil {
		return nil, err
	}

	vars, err := s.state(ctx).ConfigGet(ctx, req)
	if err != nil {
		return nil, hcerr.Externalize(hclog.FromContext(ctx), err, "failed to get config")
	}

	return &pb.ConfigGetResponse{Variables: vars}, nil
}

func (s *Service) SetConfigSource(
	ctx context.Context,
	req *pb.SetConfigSourceRequest,
) (*empty.Empty, error) {
	if err := ptypes.ValidateSetConfigSourceRequest(req); err != nil {
		return nil, err
	}

	if err := s.state(ctx).ConfigSourceSet(ctx, req.ConfigSource); err != nil {
		return nil, hcerr.Externalize(
			hclog.FromContext(ctx),
			err,
			"failed to set config source",
		)
	}

	return &empty.Empty{}, nil
}

func (s *Service) DeleteConfigSource(
	ctx context.Context,
	req *pb.DeleteConfigSourceRequest,
) (*empty.Empty, error) {
	if err := ptypes.ValidateDeleteConfigSourceRequest(req); err != nil {
		return nil, err
	}

	if err := s.state(ctx).ConfigSourceDelete(ctx, req.ConfigSource); err != nil {
		return nil, hcerr.Externalize(
			hclog.FromContext(ctx),
			err,
			"failed to delete config source",
		)
	}

	return &empty.Empty{}, nil
}

func (s *Service) GetConfigSource(
	ctx context.Context,
	req *pb.GetConfigSourceRequest,
) (*pb.GetConfigSourceResponse, error) {
	if err := ptypes.ValidateGetConfigSourceRequest(req); err != nil {
		return nil, err
	}

	vars, err := s.state(ctx).ConfigSourceGet(ctx, req)
	if err != nil {
		return nil, hcerr.Externalize(
			hclog.FromContext(ctx),
			err,
			"failed to get config source",
		)
	}

	return &pb.GetConfigSourceResponse{ConfigSources: vars}, nil
}
